\name{LoadDataFile}
\alias{LoadDataFile}
\title{
  Load Data From File Into Environment
}
\description{
  This function receives a 'work piece', a named list which contains information on a data file to be loaded.
  It can be run in 'explore' mode or in 'load' mode.
  When running in 'explore' mode, the metadata of the file is read and the sizes of the dimensions in the file are returned in a named list:
    'nmemb': Number of members
    'nltime': Number of lead-times
    'lon': Longitudes in the file
    'lat': Latitudes in the file
  When running in 'load' mode it loads and performs any requested computations in additional parameters in the 'work piece', such as interpolating, slicing, ..., and finally stores it in a shared memory matrix pointed by the parameter 'out_pointer' in the 'work piece'.
}
\usage{
  LoadDataFile(work_piece, explore_dims = FALSE, silent = FALSE)
}
\arguments{
  \item{work_piece}{
    Named list with information on the file to load or explore and additional parameters.
    The needed variables in the work piece are:
    - In explore mode:
     · dataset_type: 'exp'/'obs'
     · filename: full path to the data file
     · namevar: name of the variable in the nc file
     · is_2d_var: TRUE/FALSE
     · grid: common grid into which interpolate or NULL if no interpolation
     · remap: interpolation method ('remapbil'/'remapdis'/'remapcon'/'remapbic')
     · lon_limits: c(lon_min, lon_max)
     · lat_limits: c(lat_min, lat_max)
     · is_file_per_member: TRUE/FALSE
    - In load mode:
     · dataset_type: 'exp'/'obs'
     · filename: full path to the data file
     · namevar: name of the variable in the nc file
     · is_2d_var: TRUE/FALSE
     · grid: common grid into which interpolate or NULL if no interpolation
     · remap: interpolation method ('remapbil'/'remapdis'/'remapcon'/'remapbic')
     · lon_limits: c(lon_min, lon_max)
     · lat_limits: c(lat_min, lat_max)
     · is_file_per_dataset: TRUE/FALSE
     · startdates: in the case that filename points to a whole dataset file, the list of starting dates to load must be specified. c('sdate1', 'sdate2', ...)
     · out_pointer: big.matrix descriptor pointing to the array (transformed into a matrix) where to keep the data
     · dims: named list with dimension sizes of the original array into which the data is kept. Names must be c(['nlon'], ['nlat'], 'nltime', 'nmember', 'nsdates', 'ndat').
     · indices: vector of initial positions corresponding to each dimension in 'dims' where to store data in the original array. First two indices ('nlon', 'nlat') can be missing.
     · nmember: number of members expected to be loaded
     · mask: complete (untrimmed + interpolated if needed) mask to activate/deactivate data points, with dimensions c('lon', 'lat')
     · leadtimes: vector of time indices to be loaded from the file
     · var_limits: c(var_min, var_max)
  }
  \item{explore_dims}{
    Run in dimension explore mode (TRUE) or in load and calculation mode (FALSE).
    Takes by default the value FALSE (calculation mode).
  }
  \item{silent}{
    Parameter to allow (FALSE) or deactivate (TRUE) printing of explanatory messages.
    When deactivated any warning messages will still be displayed.
    Takes by default the value FALSE (verbose mode).
  }
}
\value{
  When called in 'explore' mode, a named list is returned with the found lengths for members, leadtimes and the latitudes and longitudes already trimmed and reordered if needed. The names are 'nmemb', 'nltime', 'lon', 'lat'. If it is a file from a file-per-member dataset, the number of files that match the filename replacing the $MEMBER$ part by an asterisk is returned (which is the supposed number of members). There are known issues with this method of detection. See documentation on parameter 'nmember' and 'nmemberobs' in Load() function.
  When called in 'calculation' mode, TRUE is returned if the file was found and FALSE is returned otherwise.  
}
\examples{
  #LoadDataFile(list(dataset_type = 'exp', filename = '/path/to/file.nc', namevar = 'tos', is_2d_var = TRUE, grid = NULL, lon_limits = c(0, 360), lat_limits = c(-90, 90), is_file_per_member = FALSE), explore_dims = TRUE, silent = FALSE)
}
\author{
  History:
  0.1  -  2015-01  (N. Manubens, \email{nicolau.manubens@ic3.cat})  -  First version
}
\keyword{datagen}
